@@ -253,7 +253,7 @@ def save_to_project(save_fn: callable, file_path: str, *args, file_path_arg_pos:
 
     cleanup_cache = False
     if cache_workspace is None:
-        cleanup = False
+        cleanup_cache = True
         cache_workspace = CacheWorkspace(path_to_exe=path_to_workspace_tools)
     # if we have write access to the target directory, we can write directly
     # there
@@ -271,7 +271,7 @@ def save_to_project(save_fn: callable, file_path: str, *args, file_path_arg_pos:
         output = save_fn(*args, **kw)
         waitfor(dm.dtcp(str(temp_file), str(full_path)), quiet=quiet)
         print('target file: {}'.format(str(full_path)))
-    if cleanup:
+    if cleanup_cache:
         cache_workspace.cleanup()
     return output
 
